==> hoteldruid-mod-ca_2.1.3-1.tar.gz: ca/visualizza_contratto.php <==
<?php

switch ($messaggio) {

case "via":  				$messaggio = "carrer"; break;
case "Torna indietro":  		$messaggio = "Torna enrere"; break;
case "Da":  				$messaggio = "Remitent"; break;
case "A":  				$messaggio = "Destinatari"; break;
case "Oggetto":  			$messaggio = "Assumpte"; break;
case "Allega":  			$messaggio = "Adjuntar"; break;
case "Spedisci":  			$messaggio = "Enviar"; break;
case "L'email a":  			$messaggio = "L'email a"; break;
case "è stata inviata":  		$messaggio = "ha estat enviat"; break;
case "bcc a":  				$messaggio = "BCC a"; break;
case "Non si è potuto inviare l'email a":	$messaggio = "No s'ha pogut enviar l'email a"; break;
case "<span class=\"colblu\">salvato</span> come":	$messaggio = "<span class=\"colblu\">desat</span> como"; break;
case "Cancella il documento":  		$messaggio = "Esborrar el document"; break;
case "Cancella i documenti":  		$messaggio = "Esborrar els documents"; break;
case "Il documento":  			$messaggio = "El document"; break;
case "è stato <b style=\"font-weight: normal; color: blue;\">cancellato</b>":	$messaggio = "ha estat <b style=\"font-weight: normal; color: blue;\">esborrat</b>"; break;
case "Transazione <font color=\"red\">scaduta</font>":	$messaggio = "Transacció <font color=\"red\">caducada</font>"; break;
case "Sovrascrivi":  			$messaggio = " Sobreescriure"; break;
case "Documenti già esistenti riguardanti questa prenotazione":	$messaggio = "Documents ja existents d'aquesta reserva"; break;
case "Documenti già esistenti riguardanti queste prenotazioni":	$messaggio = "Documents ja existents d'aquestes reserves"; break;
case "Salva dei nuovi documenti":  	$messaggio = "Desar documents nous"; break;
case "Salva un nuovo documento":  	$messaggio = "Desar un document nou"; break;
case "<span class=\"colblu\">Attenzione</span>: una email con lo stesso oggetto è già stata inviata al cliente":	$messaggio = "<span class=\"colblu\">Atenció</span>: un email amb el mateix assumpte ja havia estat enviat al client"; break;
case "documento":  			$messaggio = "document"; break;
case "Errore":  			$messaggio = "Error"; break;
case "ha scritto":  			$messaggio = "wrote"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)



?>

==> hoteldruid-mod-ca_3.0.8-1.tar.gz: ca/visualizza_contratto.php <==
<?php

switch ($messaggio) {

case "via":  				$messaggio = "carrer"; break;
case "Torna indietro":  		$messaggio = "Torna enrere"; break;
case "Da":  				$messaggio = "Remitent"; break;
case "A":  				$messaggio = "Destinatari"; break;
case "Oggetto":  			$messaggio = "Assumpte"; break;
case "Allega":  			$messaggio = "Adjuntar"; break;
case "Spedisci":  			$messaggio = "Enviar"; break;
case "L'email a":  			$messaggio = "L'email a"; break;
case "è stata inviata":  		$messaggio = "ha estat enviat"; break;
case "bcc a":  				$messaggio = "BCC a"; break;
case "Non si è potuto inviare l'email a":	$messaggio = "No s'ha pogut enviar l'email a"; break;
case "<span class=\"colblu\">salvato</span> come":	$messaggio = "<span class=\"colblu\">desat</span> como"; break;
case "Cancella il documento":  		$messaggio = "Esborrar el document"; break;
case "Cancella i documenti":  		$messaggio = "Esborrar els documents"; break;
case "Il documento":  			$messaggio = "El document"; break;
case "è stato <b style=\"font-weight: normal; color: blue;\">cancellato</b>":	$messaggio = "ha estat <b style=\"font-weight: normal; color: blue;\">esborrat</b>"; break;
case "Transazione <font color=\"red\">scaduta</font>":	$messaggio = "Transacció <font color=\"red\">caducada</font>"; break;
case "Sovrascrivi":  			$messaggio = " Sobreescriure"; break;
case "Documenti già esistenti riguardanti questa prenotazione":	$messaggio = "Documents ja existents d'aquesta reserva"; break;
case "Documenti già esistenti riguardanti queste prenotazioni":	$messaggio = "Documents ja existents d'aquestes reserves"; break;
case "Salva dei nuovi documenti":  	$messaggio = "Desar documents nous"; break;
case "Salva un nuovo documento":  	$messaggio = "Desar un document nou"; break;
case "<span class=\"colblu\">Attenzione</span>: una email con lo stesso oggetto è già stata inviata al cliente":	$messaggio = "<span class=\"colblu\">Atenció</span>: un email amb el mateix assumpte ja havia estat enviat al client"; break;
case "in data":  			$messaggio = "on"; break;
case "documento":  			$messaggio = "document"; break;
case "Errore":  			$messaggio = "Error"; break;
case "ha scritto":  			$messaggio = "wrote"; break;
case "Non si è potuto mascherare il mittente dell'email perchè attualmente <b class=\"colwarn\">SPF non è configurato correttamente</b> sul dominio della email":	$messaggio = "It was not possible to masquerade the sender of the email because currently <b class=\"colwarn\">SPF is not configured correctly</b> on the domain of email"; break;
case "L'utente amministratore può cambiare questa inpostazione in":	$messaggio = "The administrator user can change this setting in"; break;
case "configura e personalizza":  	$messaggio = "configure and customize"; break;
case "È stato raggiunto il numero massimo di email giornaliere":	$messaggio = "You have reached the maximum number of daily emails"; break;
case "Per mandare altre email l'utente amministratore può impostare un server remoto in":	$messaggio = "To comtinue sending emails the administrator user can set a remote server in"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)



?>
